@@ -1,2 +1,2 @@
 from .main import _import, import_all, import_attr
-from .api import im_fetch
+from .api import im_fetch, _im_fetch
